#!/usr/bin/env bash
VERSION=2.3.6
VENDOR=${VENDOR}
COMMIT_ID=${COMMIT_ID}
VENDOR_DIR="vscode-server"
if [[ "$VENDOR" == "cursor" ]]; then
    VENDOR_DIR="cursor-server"
fi
VENDOR_SERVER="code-server"
if [[ "$VENDOR" == "cursor" ]]; then
    VENDOR_SERVER="cursor-server"
fi
KUBECTL_FILE="/root/.alaya/vscode-plugin-remote/kubectl"
CLI_FILE="/root/.alaya/vscode-plugin-remote/aladdin"

set -e

shopt -s nocasematch

check_server() {
    if [[ "$VENDOR" == "cursor" ]]; then
        code_bin="/root/.${VENDOR_DIR}/bin/${COMMIT_ID}/bin/${VENDOR_SERVER}"
    else
        code_bin="/root/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/bin/${VENDOR_SERVER}"
    fi
    for i in {1..300}; do
        if [[ -f $code_bin ]]; then
            return 0
        fi
        echo "Waiting for ${VENDOR_SERVER} to start..."
        sleep 3
    done
    return 1
}

check_extension() {
    if [[ "$VENDOR" == "cursor" ]]; then
        code_bin="/root/.${VENDOR_DIR}/bin/${COMMIT_ID}/bin/${VENDOR_SERVER}"
    else
        code_bin="/root/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/bin/${VENDOR_SERVER}"
    fi
    if $code_bin serve-local --accept-server-license-terms --list-extensions --show-versions | grep -q "^alayanew.aladdin-remote@2.3.6$"; then
        return 0
    fi
    return 1
}

install_extension() {
    download_kubectl

    download_aladdin_cli

    PLUGINS=(
        "ms-python.python"
        "ms-python.debugpy"
        "ms-python.vscode-pylance"
    )

    force_flag=false
    for arg in "$@"; do
        if [[ "$arg" == "--force" ]]; then
            force_flag=true
            break
        fi
    done

    if [[ "$VENDOR" == "cursor" ]]; then
        code_bin="/root/.${VENDOR_DIR}/bin/${COMMIT_ID}/bin/${VENDOR_SERVER}"
    else
        code_bin="/root/.${VENDOR_DIR}/cli/servers/Stable-${COMMIT_ID}/server/bin/${VENDOR_SERVER}"
    fi
    echo "${code_bin}"
    for plugin in "${PLUGINS[@]}"; do
        if $code_bin serve-local --accept-server-license-terms --list-extensions | grep -q "^$plugin$"; then
            echo "Extension $plugin was already installed, skip!"
        else
            echo "Installing extension $plugin..."
            $code_bin serve-local --accept-server-license-terms --install-extension "$plugin"
        fi
    done

    if $code_bin serve-local --accept-server-license-terms --list-extensions --show-versions | grep -q "^alayanew.aladdin-remote@2.3.6$"; then
        if ! $force_flag; then
        echo "aladdin-remote.vsix was already installed, skip!"
        return
        fi
    fi

    $code_bin serve-local --accept-server-license-terms --uninstall-extension alayanew.aladdin-remote || true

    $code_bin serve-local --accept-server-license-terms --install-extension /root/.alaya/vscode-plugin-remote/aladdin-remote.vsix --force
}

vscode_setting_json() {
    settings_file="/root/.${VENDOR_DIR}/data/Machine/settings.json"
    mkdir -p "$(dirname "$settings_file")"
    json_content='{
        "files.exclude": {
            "**/.*": true
        }
    }'
    if [[ ! -f "$settings_file" ]]; then
        echo "$json_content" > "$settings_file"
    fi
}

vscode_setting_json

download_kubectl() {
    if [[ ! -f ${KUBECTL_FILE} ]]; then
        echo "download kubectl..."
        wget -qO ${KUBECTL_FILE} https://assets.alayanew.com/aladdin/dl.k8s.io/release/v1.32.0/bin/linux/amd64/kubectl && chmod +x ${KUBECTL_FILE}
    fi
    rm -f /usr/local/bin/kubectl
    ln -s ${KUBECTL_FILE} /usr/local/bin/kubectl
}

download_aladdin_cli(){
    ALADDINCLI_VERSION=$(wget -qO- https://assets.alayanew.com/aladdin/cli/version.txt)

    ALADDINCLI_URI="https://assets.alayanew.com/aladdin/cli/${ALADDINCLI_VERSION}/linux/amd64/aladdin"

    if [[ ! -f "$CLI_FILE" ]]; then
        echo "download aladdin..."
        wget "$ALADDINCLI_URI" -qO "$CLI_FILE" && chmod +x "$CLI_FILE"
    fi
    rm -f /usr/local/bin/aladdin
    ln -s "$CLI_FILE" /usr/local/bin/aladdin
}

case "$1" in
  check)
    case "$2" in
      remote)
        check_extension
        result=$?
        exit $result
        ;;
      server)
        check_server
        result=$?
        exit $result
        ;;
      *)
        echo "Unknown subcommand for $1: $2"
        exit 1
        ;;
    esac
    ;;
  install)
    case "$2" in
      remote)
        install_extension ${@:3}
        ;;
      *)
        echo "Unknown subcommand for $1: $2"
        exit 1
        ;;
    esac
    ;;
  *)
    echo "Error: Unknown command '$1'"
    exit 1
    ;;
esac
